@@ -3,8 +3,7 @@
 """ Facade to find Stopwords Data on Disk """
 
 
-from baseblock import EnvIO
-from baseblock import BaseObject
+from baseblock import BaseObject, EnvIO
 
 from fast_sentence_tokenize.datablock.dto import stopwords
 
@@ -17,7 +16,7 @@ class FindStopWords(BaseObject):
         Created:
             25-Aug-2022
             craigtrim@gmail.com
-            *   in pursuit of 
+            *   in pursuit of
                 https://github.com/grafflr/graffl-core/issues/120
         """
         BaseObject.__init__(self, __name__)
